==> production-demo-20260209_092413.tar.gz: var/www/html/production-demo/var/tmp/twig/dd/dd34c609c716d2ba7ff4eda54ef12c48.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/DashboardBundle/Assets/css/dashboard.css */
class __TwigTemplate_e8ee922d40bcce30955432c3d2345cf8 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "body:has(.s-dashboard) {
    background-color: var(--layer);
    --field: var(--field-02);
    --field-hover: var(--field-hover-02);
}

.input-group-addon label {
    margin-bottom: 0px;
}
.vector-map {
\theight: 350px;
    color: transparent;
}
.jvectormap-container {
    height:100%;
    width:100%;
}
.dashboard-widgets .sortable-placeholder {
    background-color: #fff;
    border: 1px dashed #4e5d9d;
    flex-grow: 0;
}
.dashboard-widgets.cards {
    display: -webkit-box;
    display: -webkit-flex;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-orient: vertical;
    -webkit-box-direction: normal;
    -webkit-flex-wrap: wrap;
    -ms-flex-wrap: wrap;
    flex-wrap: wrap;
    padding: 10px;
}
.dashboard-widgets .tile {
    --layer: var(--background);
    margin: 5px;
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    -moz-transition-property: background-color, box-shadow, -moz-transform, border;
    -o-transition-property: background-color, box-shadow, text-shadow, -o-transform, border;
    -webkit-transition-property: background-color, box-shadow, text-shadow, -webkit-transform, border;
    transition-property: background-color, box-shadow, text-shadow, transform, border;
    -moz-transition-duration: 0.2s;
    -o-transition-duration: 0.2s;
    -webkit-transition-duration: 0.2s;
    transition-duration: 0.2s;
    -moz-transition-timing-function: linear;
    -o-transition-timing-function: linear;
    -webkit-transition-timing-function: linear;
    transition-timing-function: linear;
    position: relative;
}
.dashboard-widgets .ui-sortable-helper .tile {
    box-shadow: rgba(255, 255, 255, 0.1) 0px 1px 1px 0px inset, rgba(50, 50, 93, 0.25) 0px 50px 100px -20px, rgba(0, 0, 0, 0.3) 0px 30px 60px -30px;
    max-width: 170px;
    max-height: 170px;
    overflow: hidden;
    transform: rotate(1deg);
    -webkit-animation: squareToCircle 1.5s .5s infinite alternate;
}

@-webkit-keyframes squareToCircle {
    0% {border-radius: 0 0 0 0;}

    100% {border-radius: 20px 20px 20px 20px;}
}

.dashboard-widgets .widget-overlay {
    content: '';
    width: 101%;
    height: 101%;
    position: absolute;
    top: 0;
    left: 0;
    transition: var(--transition-all-expressive);
    backdrop-filter: blur(0);
    pointer-events: none;
    opacity: 0;
}
.dashboard-widgets .ui-sortable-helper .widget-overlay {
    backdrop-filter: blur(8px);
    opacity: 1;
}

.dashboard-widgets h4 {
    cursor: -moz-grab;
    cursor: -webkit-grab;
    cursor: grab;
}
.dashboard-widgets .dropdown-toggle .ri-more-2-fill {
    display: inline-block;
    font-size: 15px;
    color: var(--icon-secondary);
    transition: var(--transition-all-productive);
    width: 30px;
    margin: -10px;
    text-align: center;
    line-height: 30px;
    border-radius: var(--border-radius-md);
}
.dashboard-widgets .card-header h4 {
    width: 90%;
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
}
.dashboard-widgets .tile table {
    table-layout: fixed;
}
.dashboard-widgets .tile table td {
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
}
.dashboard-widgets .tile table td:last-child {
    width: 30px;
}

.chart-wrapper {
    position: relative;
}
.chart-wrapper .legend {
    background: #000;
    opacity: 0;
    position: absolute;
    bottom: -17px;
    width: 100%;
    -moz-border-radius: 0 0 4px 4px;
    -webkit-border-radius: 0 0 4px 4px;
    border-radius: 0 0 4px 4px;
    color: #fff;
    -webkit-transition: all 0.3s ease-in-out;
}
.chart-wrapper:hover .legend {
    opacity: 0.8;
}
.chart-wrapper .legend ul {
    list-style: none;
    margin: 0;
    padding: 5px 0;
}
.chart-wrapper .legend li {
    margin: 0 10px;
    padding: 5px 0;
}
.chart-wrapper .legend li span {
    display: inline-block;
    width: 14px;
    height: 8px;
    margin-right: 5px;
    -moz-border-radius: 4px;
    -webkit-border-radius: 4px;
    border-radius: 4px;
}

@media (max-width: 700px) {
    .dashboard-widgets .widget {
        width: 100% !important;
    }
}

#dashboard-widgets .spinner {
    text-align: center;
    line-height: 250px;
    font-size: 24px;
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/DashboardBundle/Assets/css/dashboard.css";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/DashboardBundle/Assets/css/dashboard.css", "/var/www/html/mauticGIT-Test/app/bundles/DashboardBundle/Assets/css/dashboard.css");
    }
}

==> production-demo-20260209_093043.tar.gz: var/www/html/production-demo/var/tmp/twig/dd/dd34c609c716d2ba7ff4eda54ef12c48.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/DashboardBundle/Assets/css/dashboard.css */
class __TwigTemplate_e8ee922d40bcce30955432c3d2345cf8 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "body:has(.s-dashboard) {
    background-color: var(--layer);
    --field: var(--field-02);
    --field-hover: var(--field-hover-02);
}

.input-group-addon label {
    margin-bottom: 0px;
}
.vector-map {
\theight: 350px;
    color: transparent;
}
.jvectormap-container {
    height:100%;
    width:100%;
}
.dashboard-widgets .sortable-placeholder {
    background-color: #fff;
    border: 1px dashed #4e5d9d;
    flex-grow: 0;
}
.dashboard-widgets.cards {
    display: -webkit-box;
    display: -webkit-flex;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-orient: vertical;
    -webkit-box-direction: normal;
    -webkit-flex-wrap: wrap;
    -ms-flex-wrap: wrap;
    flex-wrap: wrap;
    padding: 10px;
}
.dashboard-widgets .tile {
    --layer: var(--background);
    margin: 5px;
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    -moz-transition-property: background-color, box-shadow, -moz-transform, border;
    -o-transition-property: background-color, box-shadow, text-shadow, -o-transform, border;
    -webkit-transition-property: background-color, box-shadow, text-shadow, -webkit-transform, border;
    transition-property: background-color, box-shadow, text-shadow, transform, border;
    -moz-transition-duration: 0.2s;
    -o-transition-duration: 0.2s;
    -webkit-transition-duration: 0.2s;
    transition-duration: 0.2s;
    -moz-transition-timing-function: linear;
    -o-transition-timing-function: linear;
    -webkit-transition-timing-function: linear;
    transition-timing-function: linear;
    position: relative;
}
.dashboard-widgets .ui-sortable-helper .tile {
    box-shadow: rgba(255, 255, 255, 0.1) 0px 1px 1px 0px inset, rgba(50, 50, 93, 0.25) 0px 50px 100px -20px, rgba(0, 0, 0, 0.3) 0px 30px 60px -30px;
    max-width: 170px;
    max-height: 170px;
    overflow: hidden;
    transform: rotate(1deg);
    -webkit-animation: squareToCircle 1.5s .5s infinite alternate;
}

@-webkit-keyframes squareToCircle {
    0% {border-radius: 0 0 0 0;}

    100% {border-radius: 20px 20px 20px 20px;}
}

.dashboard-widgets .widget-overlay {
    content: '';
    width: 101%;
    height: 101%;
    position: absolute;
    top: 0;
    left: 0;
    transition: var(--transition-all-expressive);
    backdrop-filter: blur(0);
    pointer-events: none;
    opacity: 0;
}
.dashboard-widgets .ui-sortable-helper .widget-overlay {
    backdrop-filter: blur(8px);
    opacity: 1;
}

.dashboard-widgets h4 {
    cursor: -moz-grab;
    cursor: -webkit-grab;
    cursor: grab;
}
.dashboard-widgets .dropdown-toggle .ri-more-2-fill {
    display: inline-block;
    font-size: 15px;
    color: var(--icon-secondary);
    transition: var(--transition-all-productive);
    width: 30px;
    margin: -10px;
    text-align: center;
    line-height: 30px;
    border-radius: var(--border-radius-md);
}
.dashboard-widgets .card-header h4 {
    width: 90%;
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
}
.dashboard-widgets .tile table {
    table-layout: fixed;
}
.dashboard-widgets .tile table td {
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
}
.dashboard-widgets .tile table td:last-child {
    width: 30px;
}

.chart-wrapper {
    position: relative;
}
.chart-wrapper .legend {
    background: #000;
    opacity: 0;
    position: absolute;
    bottom: -17px;
    width: 100%;
    -moz-border-radius: 0 0 4px 4px;
    -webkit-border-radius: 0 0 4px 4px;
    border-radius: 0 0 4px 4px;
    color: #fff;
    -webkit-transition: all 0.3s ease-in-out;
}
.chart-wrapper:hover .legend {
    opacity: 0.8;
}
.chart-wrapper .legend ul {
    list-style: none;
    margin: 0;
    padding: 5px 0;
}
.chart-wrapper .legend li {
    margin: 0 10px;
    padding: 5px 0;
}
.chart-wrapper .legend li span {
    display: inline-block;
    width: 14px;
    height: 8px;
    margin-right: 5px;
    -moz-border-radius: 4px;
    -webkit-border-radius: 4px;
    border-radius: 4px;
}

@media (max-width: 700px) {
    .dashboard-widgets .widget {
        width: 100% !important;
    }
}

#dashboard-widgets .spinner {
    text-align: center;
    line-height: 250px;
    font-size: 24px;
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/DashboardBundle/Assets/css/dashboard.css";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/DashboardBundle/Assets/css/dashboard.css", "/var/www/html/production-demo/app/bundles/DashboardBundle/Assets/css/dashboard.css");
    }
}
